@@ -30,5 +30,5 @@
  * under the License.
  */
 
-require('./no_transpilation');
+require("./no_transpilation");
 require('@osd/optimizer').registerNodeAutoTranspilation();
\ No newline at end of file
